@@ -1,4 +1,4 @@
-case $(uname -s) in *-WOW64) wow64=" (32-bit)" ;; esac
+case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
 /bin/rm -f "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}/GNOME-Openbox.lnk"
 /bin/rm -f "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}/KDE-Openbox.lnk"
 /bin/rm -f "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}/Openbox.lnk"
